        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,2,3,6,7,8,9,12,16,18,22,23,24,25,27,31,32,34,35,36,37,43,44,47,48,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 25 <br>1,4,5,10,11,13,14,15,17,19,20,21,26,28,29,30,33,38,39,40,41,42,45,46,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,2,3,6,7,8,9,12,16,18,22,23,24,25,27,31,32,34,35,36,37,43,44,47,48,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 25 <br>1,4,5,10,11,13,14,15,17,19,20,21,26,28,29,30,33,38,39,40,41,42,45,46,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,2,3,6,7,8,9,12,16,18,22,23,24,25,27,31,32,34,35,36,37,43,44,47,48,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 25 <br>1,4,5,10,11,13,14,15,17,19,20,21,26,28,29,30,33,38,39,40,41,42,45,46,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,2,3,6,7,8,9,12,16,18,22,23,24,25,27,31,32,34,35,36,37,43,44,47,48,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 25 <br>1,4,5,10,11,13,14,15,17,19,20,21,26,28,29,30,33,38,39,40,41,42,45,46,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>8</strong> miembros: 26 <strong>control</strong><br>0,2,3,6,7,8,9,12,16,18,22,23,24,25,27,31,32,34,35,36,37,43,44,47,48,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260626 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 25 <br>1,4,5,10,11,13,14,15,17,19,20,21,26,28,29,30,33,38,39,40,41,42,45,46,50';}
}
